import { Job } from "bull";
import { logger } from "../logger";
import { env } from "../../env";
import { fetchImage } from "../utils";

export const liquidRescaleProcess = async (job: Job) => {
    logger.info({ id: job.id, data: job.data }, 'Processing liquid rescale job');

    const { imageUrl } = job.data;

    const image = await fetchImage(imageUrl);

    const formData = new FormData();
    formData.append('file', new Blob([image]));

    let result;

    try {
        result = await fetchImage(env.LIQUID_RESCALE_API_URL, { method: 'POST', body: formData });
    } catch (err) {
        logger.error(err);
        return Promise.reject(err);
    }

    // return Promise.resolve({ data: result.toString('base64') });
    return Promise.resolve(result);
};